<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="5">
            <el-form-item label="订单状态：">
              <el-select clearable v-model="querys[3].value" placeholder="请选择">
                <el-option v-for="item in options" :key="item.value" :label="item.label" :value="item.value">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="7">
            <el-form-item label="下单日期：">
              <el-date-picker v-model="querys[2].value" type="daterange" range-separator="至" start-placeholder="开始日期"
                end-placeholder="结束日期" value-format="yyyy-MM-dd">
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="订单标题：">
              <el-input v-model="querys[0].value" clearable placeholder="请输入订单标题" />
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
          </el-col>
        </el-row>
        <!-- <el-form-item label="采购部门：">
              <el-input
                v-model="querys[1].value"
                clearable
                placeholder="请输入采购部门"
              />
            </el-form-item> -->
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content">
        <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
        <!-- <el-button
          plain
          icon="el-icon-tickets"
          type="primary"
          @click="monthApplication"
          >当月申请单({{ applicationMonthLength }})</el-button
        > -->
        <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
          <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
            style="margin-left: 10px">删除</el-button>
        </el-popconfirm>
      </div>
      <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
        :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
        :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
        @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55" />
        <el-table-column fixed type="index" width="55" label="序号" />
        <el-table-column fixed prop="code" label="订单号" show-overflow-tooltip />
        <el-table-column fixed prop="planTitle" label="订单标题" min-width="150" show-overflow-tooltip />
        <el-table-column fixed prop="orgName" label="采购部门" show-overflow-tooltip />
        <el-table-column fixed prop="planUserName" label="采购执行人" show-overflow-tooltip />
        <el-table-column fixed prop="planDate" label="下单日期" show-overflow-tooltip />
        <el-table-column fixed label="订单状态" width="90" prop="status">
          <template slot-scope="scope">
            <el-tag v-if="scope.row.status === '1'" type="">已下单</el-tag>
            <el-tag v-else-if="scope.row.status === '2'" type="success">已入库</el-tag>
            <el-tag v-else-if="scope.row.status === '3'" type="primary">已完成</el-tag>
          </template>
        </el-table-column>
        <el-table-column fixed prop="totalPrice" label="预计金额" min-width="70" show-overflow-tooltip />
        <el-table-column prop="completeDate" label="完成时间" min-width="120" show-overflow-tooltip />
        <!-- <el-table-column prop="createTime" label="创建时间" show-overflow-tooltip /> -->
        <el-table-column label="操作">
          <template slot-scope="scope">
            <el-button @click="printMask(scope.row)" type="primary" plain size="mini">打印</el-button>
            <el-button v-show="false" size="small" type="primary" ref="import" v-print="printMe">导入</el-button>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
        :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total"
        @size-change="handleSizeChange" @current-change="handleCurrentChange" />
    </div>
    <div v-show="false">
      <div class="printAvailable" id="printAvailable">
        <div>
          <div class="print-title">{{ printTitle }}</div>
          <p id="step2" class="from-title">
            <i class="el-icon-info" />
            <span>采购物资明细</span>
          </p>
          <el-table class="printqualification" border size="mini" :style="{ width: '100%' }"
            :row-style="{ height: '40px' }" :header-row-style="{ height: '40px' }"
            :cell-style="{ 'text-align': 'center' }" :header-cell-style="{ 'text-align': 'center' }"
            :data="purMaterialsData">
            <el-table-column prop="name" label="物资名称" width="200px">
            </el-table-column>
            <el-table-column prop="model" label="型号" width="120px">
            </el-table-column>
            <el-table-column prop="unit" label="计量单位" width="100px">
            </el-table-column>
            <el-table-column prop="price" label="单价" width="100px">
            </el-table-column>
            <el-table-column prop="quantity" label="采购数量" width="100px">
            </el-table-column>
            <el-table-column prop="actualQuantity" label="实际采购数量" width="100px">
              <template slot-scope="scope">
                <el-input v-model="scope.row.actualQuantity" maxlength="50" size="mini" />
              </template>
            </el-table-column>
          </el-table>
        </div>
        <div class="sign">
          <div></div>
          <div>
            <p>&emsp;部门领导：<span></span></p>
            <p>综合部领导：<span></span></p>
            <p>&emsp;确认时间：<span></span></p>
          </div>
        </div>
      </div>
    </div>
    <purchaseScheduleDialog ref="formModal"></purchaseScheduleDialog>
    <!-- <el-dialog width="56%" title="当月申请单" :visible.sync="dialogVisible">
      <el-table
        border
        class="application"
        size="mini"
        :cell-style="{'text-align': 'center'}"
        :header-cell-style="{'text-align': 'center'}"
        :data="gridData"
      >
        <el-table-column prop="code" label="申请单号" width="130">
        </el-table-column>
        <el-table-column prop="applyTitle" label="申请标题" width="100">
        </el-table-column>
        <el-table-column
          prop="applicationDeptName"
          label="申请部门"
          width="150"
        >
        </el-table-column>
        <el-table-column prop="applicantName" label="申请人" width="100">
        </el-table-column>
        <el-table-column prop="applicationDate" label="申请日期" width="120">
        </el-table-column>
        <el-table-column prop="lastTime" label="确认时间"> </el-table-column>
      </el-table>
    </el-dialog> -->
  </div>
</template>

<script>
import Print from 'vue-print-nb'
import { TableMixin } from '@/mixins/tableMixin'
import purchasingManage from '@/api/manager/material/purchasingManage.js'
import purchaseSchedule from './api/PurchaseSchedule'
import purchaseScheduleDialog from '@/views/Manage/material/components/PurchaseScheduleDialog.vue'

export default {
  directives: { Print },
  name: 'PurchasingManage',
  components: {
    purchaseScheduleDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      printTitle: '',
      printMe: {
        // 打印区域
        id: 'printAvailable',
        // 是否有打印预览
        preview: false
      },
      purMaterialsData: [],
      applicationMonthLength: '',
      //当月申请单数据
      // gridData: [],
      // dialogVisible: false,
      url: {
        delete: '/manager/material/purchasing/delete/'
      },
      options: [
        {
          value: '1',
          label: '已下单'
        },
        {
          value: '2',
          label: '已完成'
        },
        {
          value: '3',
          label: '进行中'
        }
      ],
      inquire: {
        title: '',
        sector: '',
        state: '',
        data: ''
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'planTitle',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'orgName',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'planDate',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'status',
          relation: 'AND',
          value: ''
        }
      ],
      StshowFormDias: false
      // fuelTypes: []
    }
  },
  created() {
    // this.applicationMonth()
    // this.fuelTypes = dictContracts.getDictItemsFromCache('cmgt_rylx')
  },
  mounted() { },
  methods: {
    printMask(item) {
      purchaseSchedule.entitiesQuery(item.id, res => {
        console.log(res)
        this.printTitle = res.planTitle
        this.purMaterialsData = res.detailList
        this.$refs.import.$el.click()
      })
    },
    //获取当月申请单列表
    // applicationMonth() {
    //   let applicationMonthData = {
    //     groupRelation: 'AND',
    //     pageBean: {
    //       page: 1,
    //       pageSize: 10,
    //       showTotal: true
    //     },
    //     querys: [
    //       {
    //         group: 'main',
    //         operation: 'EQUAL',
    //         parentGroup: '',
    //         property: 'status',
    //         relation: 'AND',
    //         value: '2'
    //       }
    //     ],
    //     sorter: [
    //       {
    //         direction: 'ASC',
    //         property: 'sn'
    //       }
    //     ]
    //   }
    //   purchaseSchedule.purchasingCount(applicationMonthData, res => {
    //     // console.log('-------------load-------------')
    //     console.log(res)
    //     // this.total = res.total
    //     this.gridData = res.value
    //     this.applicationMonthLength = res.value.length
    //     // this.commonApiData()
    //     // this.loading = false
    //   })
    // },
    //当月申请单
    // monthApplication() {
    //   this.dialogVisible = true
    // },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
      this.querys[3].value = ''
    },
    // 获取list
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }

      this.queryParam.sorter = [
        {
          direction: 'DESC',
          property: 'sn'
        }
      ]

      purchaseSchedule.orderQuery(this.queryParam, res => {
        console.log(res)
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    // 批量删除产品类型
    handleDelete() {
      purchaseSchedule
        .deleteMaterialOrder(this.multipleSelection)
        .then(res => {
          if (res.state) {
            this.$notify({
              type: 'success',
              message: '删除成功',
              duration: 2000
            })
            this.queryParam.pageBean.page = 1
            this.loadData()
          }
        })
        .catch(res => {
          this.$notify({
            type: 'error',
            message: res.message,
            duration: 2000,
            offset: 80
          })
        })
    },
    // 修改
    handleUpdate(row) {
      console.log(row.id)
      // purchasingManage.loadMaterialDetail(row.id, res => {
      //   console.log('---res:', res)
      //   this.$refs.formModal.Update(row, res.value)
      // })
      this.$refs.formModal.Update(row)
    },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    //操作
    handleEdit() { }
  }
}
</script>
<style lang="scss" scoped>
.bbsl-scroll-form-spare {
  width: 100%;
}

.type-tag {
  margin: 0 2px;
}

.print-title {
  width: 100%;
  font-size: 24px;
  text-align: center;
  font-weight: bold;
  margin-bottom: 20px;
}

.margin-top {
  margin-bottom: 20px;
}

.from-title-print {
  color: #409eff;
  padding: 30px 0 30px 0;
  font-size: 14px;
  font-weight: 700;
  vertical-align: middle;
}

.printAvailable {
  .sign {
    display: flex;
    justify-content: space-between;

    p {
      margin-top: 60px;

      span {
        display: inline-block;
        width: 200px;
        border-bottom: 1px solid #000;
      }
    }
  }
}
</style>
<style media="print" lang="scss">
@page {
  size: auto;
  margin: 0mm;
}

@media print {
  html {
    background-color: #ffffff;
    height: auto;
    margin: 0px;
  }

  body {
    border: solid 1px #ffffff;
    margin: 10mm 15mm 10mm 15mm;
  }

  table {
    table-layout: auto !important;
  }

  .el-table__header-wrapper .el-table__header {
    width: 100% !important;
    border: solid 1px #ebeef5;
    border-bottom: 0;
  }

  .el-table__body-wrapper .el-table__body {
    width: 100% !important;
    border: solid 1px #ebeef5;
    border-top: 0;
  }

  .el-table--border {
    width: 100% !important;
    border: solid 1px #ebeef5;
    border-right: 0;
    border-bottom: 0;
  }

  .el-table--border th,
  .el-table--border td {
    border-right: 1px solid #ebeef5 !important;
  }

  #pagetable table {
    table-layout: fixed !important;
  }

  .el-table .cell {
    line-height: 140% !important;
  }
}
</style>

<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
